#include <ncurses.h>
#include <stdlib.h>
#include <ctype.h>

#include "Engine.h"

int main() {
	/***** NCURSES START *****/
	initscr(); noecho(); curs_set(0);
	/* <<< SET-UP >>> */
	// Create a board for the snake to run inside.
	Board board;
	Board_Create(&board);
	box(board.win, 0, 0);
	refresh();
	// Create var for snake and it's length.
	Snake_t* p_snake = NULL;
	unsigned int snake_length = 5;
	/* <<< RUN GAME >>> */
	// Run game til user decide to quit.
	char restart = 'Y';
	while (toupper(restart) == 'Y') {
		// Erase the quit hint.
		mvwprintw(stdscr, board.yLoc + board.height/2, board.xLoc + board.width/2 - 20,
				"                                 ");
		/* <<< SNAKE >>> */
		// Create a snake inside the board with length of 5 Snake_t nodes.
		Snake_Init(&board, &p_snake, snake_length);
		if (p_snake == NULL) {
			mvwprintw(stdscr, board.yLoc - 1, board.xLoc + 2,
					"Could not allocate memory for snake!");
			wrefresh(stdscr);
			getch();
			return EXIT_FAILURE;
		}
		/* <<< RUN SNAKE >>> */
		Engine_Run(&board, p_snake, &snake_length);
		// De-allocate memory for the snake.
		Snake_Free(&p_snake);
		// Reset snake's length to 5.
		snake_length = 5;
		/* <<< QUIT || RESTART >>> */
		// Print quit hint.
		mvwprintw(stdscr, board.yLoc + board.height/2, board.xLoc + board.width/2 - 20,
				"Press [Y] to restart; [Q] to quit");
		// Refresh standard screen.
		refresh(); 
		// Get input to quit or restart.
		restart = 'i';
		while (toupper(restart) != 'Y' && toupper(restart) != 'Q') {
			restart = getch();
		}
	}
	endwin();
	/***** NCURSES END *****/
	return EXIT_SUCCESS;
}
