#include "Engine.h"

#ifndef _SNAKE_H_
#define _SNAKE_H_

#define SNAKE_HEAD '+'

/* * *
 * This struct represents a single node of a snake.
 * * */
typedef struct Snake_t {
	char vHead;				/* Value for the head of the snake. */
	unsigned int vBody;		/* Value for the body of the snake. */
	unsigned int yLoc;		/* Horizontal coordinate (row). */
	unsigned int xLoc;		/* Vertical coordinate (column). */
	struct Snake_t* next;	/* Pointer to the next node. */
} Snake_t;

/* * *
 * De-allocate heap memory for the snake passed in.
 * * */
void Snake_Free(Snake_t** snake);

/* * *
 * Allocate memory on the heap for snake with length passed in.
 * Initialize it with data from board passed in.
 * * */
void Snake_Init(const Board* board, Snake_t** snakeHead, const unsigned int length);

/* * *
 * Draw the whole snake inside the window of board.
 * * */
void Snake_Draw(const Board* board, Snake_t** snakeHead);

/* * *
 * Add a new node to the head of the snake with the coordinate values passed in.
 * * */
void Snake_Add(Snake_t** snake, unsigned int yLoc, unsigned int xLoc);

/* * *
 * Erase the whole snake inside the window of board.
 * * */
void Snake_Erase(const Board* board, Snake_t** snake);

/* * *
 * Stepping the whole snake along before moving the head of snake left by one.
 * * */
void Snake_Move_Left(Snake_t** snake);

/* * *
 * Stepping the whole snake along before moving the head of snake up by one.
 * * */
void Snake_Move_Down(Snake_t** snake);

/* * *
 * Stepping the whole snake along before moving the head of snake down by one.
 * * */
void Snake_Move_Up(Snake_t** snake);

/* * *
 * Stepping the whole snake along before moving the head of snake right by one.
 * * */
void Snake_Move_Right(Snake_t** snake);

#endif

